# NanoBlogger script to apply autoformat's output to an entry
# permanently
# NOTE: Must be run from Nanoblogger's BASE_DIR

BLOG_DIR="$1"

# show help
if [ -z "$BLOG_DIR" ]; then
	echo "usage: `basename $0` [blog_dir]"; exit 1
fi
# die if bad blog directory is given
if [ ! -d "$BLOG_DIR/archives" ]; then
	echo "blog directory '$BLOG_DIR' doesn't exist. bye"; exit 1
fi

# load blog's config
if [ -f "$BLOG_DIR/blog.conf" ]; then
	. "$BLOG_DIR/blog.conf"
fi
# check for plugins
if [ -d "$BLOG_DIR/plugins/autoformat" ]; then
	echo "detected old autoformat plugins"
	echo "renaming to 'old_autoformat' ..."
	mv "$BLOG_DIR/plugins/autoformat" "$BLOG_DIR/plugins/old_autoformat"
fi
if [ ! -d "plugins/autoformat" ]; then
	echo "autoformat plugins not found!"
	echo "`basename $0` must be run from nanoblogger's base directory"; exit 1
fi

# read a file's metadata
read_metadata(){
MTAG="$1"
META_FILE="$2"
NB_Metadata=`sed -n '/^'$MTAG'[\:]/p' "$META_FILE" |sed -e 's/^'$MTAG'[\:][ ]//'`
[ "$MTAG" != "BODY" ] ||
NB_Metadata=`sed -n '/^'$MTAG'[\:]/,/^[\-][\-][\-][\-][\-]/p' "$META_FILE" |sed -e '/^'$MTAG'[\:]/d; /^[\-][\-][\-][\-][\-]/d'`
}

for ENTRY_FILE in "$BLOG_DIR"/archives/*.htm; do
	echo "processing entry file: $ENTRY_FILE ..."
	# read metadata
	read_metadata TITLE "$ENTRY_FILE"; NB_EntryTitle="$NB_Metadata"
	read_metadata AUTHOR "$ENTRY_FILE"; NB_EntryAuthor="$NB_Metadata"
	read_metadata DATE "$ENTRY_FILE"; NB_EntryDate="$NB_Metadata"
	read_metadata BODY "$ENTRY_FILE"; NB_EntryBody="$NB_Metadata"
	# load plugins

	for plugin in plugins/autoformat/*.sh; do
		! [ -f "$plugin" ] ||
			. "$plugin"
	done

	# build new entry
	cat >> "$ENTRY_FILE.tmp" <<-EOF
		TITLE: $NB_EntryTitle
		AUTHOR: $NB_EntryAuthor
		DATE: $NB_EntryDate
		-----
		BODY:
		$NB_EntryBody
		-----
	EOF
	# overwrite old entry with new
	mv "$ENTRY_FILE".tmp "$ENTRY_FILE"

done
